@@ -39,6 +39,7 @@
 #include <string.h>
 #include <glib.h>
 #include <glib/gi18n.h>
+#include <glib/gstdio.h>
 #include <glib-object.h>
 #include <gtk/gtk.h>
 
@@ -543,23 +544,19 @@ eog_application_screensaver_disable (EogApplication *application)
 static void
 eog_application_load_accelerators (void)
 {
-	gchar *accelfile = g_build_filename (g_get_home_dir (),
-					     ".gnome2",
-					     "accels",
-					     "eog", NULL);
+	gchar *accelfile = g_build_filename (eog_util_dot_dir (), "accels", NULL);
 
 	/* gtk_accel_map_load does nothing if the file does not exist */
 	gtk_accel_map_load (accelfile);
+
 	g_free (accelfile);
 }
 
 static void
 eog_application_save_accelerators (void)
 {
-	gchar *accelfile = g_build_filename (g_get_home_dir (),
-					     ".gnome2",
-					     "accels",
-					     "eog", NULL);
+	/* save to XDG_CONFIG_HOME/eog/accels */
+	gchar *accelfile = g_build_filename (eog_util_dot_dir (), "accels", NULL);
 
 	gtk_accel_map_save (accelfile);
 	g_free (accelfile);
